==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/playerControls/PlayerControlsController.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.playerControls;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.panels.PlayerControlsPanel;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.model.PanelController;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.TimeUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;

/**
 * The Class PlayerControlsController.
 */
public class PlayerControlsController extends PanelController<PlayerControlsPanel> {

	/**
	 * Instantiates a new player controls controller.
	 * 
	 * @param panel
	 *            the panel
	 */
	public PlayerControlsController(PlayerControlsPanel panel) {
		super(panel);
		addBindings();
		addStateBindings();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addBindings()
	 */
	@Override
	protected void addBindings() {
		PlayerControlsListener listener = new PlayerControlsListener(getPanelControlled(), this);

		getPanelControlled().getProgressBar().addMouseListener(listener);
		getPanelControlled().getShuffleButton().addActionListener(listener);
		getPanelControlled().getRepeatButton().addActionListener(listener);
		getPanelControlled().getPlayButton().addMouseListener(listener);
		getPanelControlled().getStopButton().addMouseListener(listener);
		getPanelControlled().getNextButton().addMouseListener(listener);
		getPanelControlled().getPreviousButton().addMouseListener(listener);
		getPanelControlled().getVolumeButton().addActionListener(listener);
		getPanelControlled().getVolumeSlider().addChangeListener(listener);
		getPanelControlled().getBalanceSlider().addChangeListener(listener);
		getPanelControlled().getKaraokeButton().addActionListener(listener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addStateBindings()
	 */
	@Override
	protected void addStateBindings() {
		getPanelControlled().getShuffleButton().setSelected(Kernel.getInstance().state.isShuffle());
		getPanelControlled().getRepeatButton().setSelected(Kernel.getInstance().state.isRepeat());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#notifyReload()
	 */
	@Override
	protected void notifyReload() {
		// Nothing to do
	}

	/**
	 * Sets the karaoke.
	 * 
	 * @param karaoke
	 *            the new karaoke
	 */
	public void setKaraoke(boolean karaoke) {
		getPanelControlled().getKaraokeButton().setSelected(karaoke);
		getPanelControlled().getKaraokeEnabledLabel().setVisible(karaoke);
	}

	/**
	 * Sets the max duration.
	 * 
	 * @param maxDuration
	 *            the new max duration
	 */
	public void setMaxDuration(long maxDuration) {
		getLogger().debug(LogCategories.CONTROLLER, new String[] { Long.toString(maxDuration) });

		getPanelControlled().getProgressBar().setMaximum((int) maxDuration);
	}

	/**
	 * Sets the mute.
	 * 
	 * @param mute
	 *            the new mute
	 */
	public void setMute(boolean mute) {
		getPanelControlled().getVolumeButton().setSelected(mute);
		if (mute) {
			getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MUTE);
		} else {
			int value = getPanelControlled().getVolumeSlider().getValue();
			if (value > 80)
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOlUME_MAX);
			else if (value > 40)
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MED);
			else if (value > 5)
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MIN);
			else
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_ZERO);
		}
	}

	/**
	 * Sets the playing.
	 * 
	 * @param playing
	 *            the new playing
	 */
	public void setPlaying(boolean playing) {
		getPanelControlled().setPlaying(playing);
	}

	/**
	 * Sets the repeat.
	 * 
	 * @param repeat
	 *            the new repeat
	 */
	public void setRepeat(boolean repeat) {
		getPanelControlled().getRepeatButton().setSelected(repeat);
	}

	/**
	 * Sets the shuffle.
	 * 
	 * @param shuffle
	 *            the new shuffle
	 */
	public void setShuffle(boolean shuffle) {
		getPanelControlled().getShuffleButton().setSelected(shuffle);
	}

	/**
	 * Sets the slidable.
	 * 
	 * @param slidable
	 *            the new slidable
	 */
	public void setSlidable(boolean slidable) {
		getPanelControlled().getProgressBar().setEnabled(slidable);
	}

	/**
	 * Sets the time.
	 * 
	 * @param time
	 *            the time
	 * @param totalTime
	 *            the total time
	 */
	public void setTime(long time, long totalTime) {
		long remainingTime = totalTime - time;
		if (time == 0)
			getPanelControlled().getRemainingTime().setText(TimeUtils.milliseconds2String(time));
		else
			getPanelControlled().getRemainingTime().setText(remainingTime > 0 ? StringUtils.getString("- ", TimeUtils.milliseconds2String(remainingTime)) : "-");

		getPanelControlled().getTime().setText(TimeUtils.milliseconds2String(time));
		getPanelControlled().getProgressBar().setValue((int) time);
	}

	/**
	 * Sets the volume.
	 * 
	 * @param value
	 *            the new volume
	 */
	protected void setVolume(int value) {
		getPanelControlled().getVolumeSlider().setValue(value);
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/playerControls/PlayerControlsController.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.playerControls;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.panels.PlayerControlsPanel;
import net.sourceforge.atunes.kernel.controllers.model.PanelController;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.TimeUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;

/**
 * The Class PlayerControlsController.
 */
public class PlayerControlsController extends PanelController<PlayerControlsPanel> {

	/**
	 * Instantiates a new player controls controller.
	 * 
	 * @param panel
	 *            the panel
	 */
	public PlayerControlsController(PlayerControlsPanel panel) {
		super(panel);
		addBindings();
		addStateBindings();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.kernel.controllers.model.Controller#addBindings()
	 */
	@Override
	protected void addBindings() {
		PlayerControlsListener listener = new PlayerControlsListener(getPanelControlled(), this);

		getPanelControlled().getProgressBar().addMouseListener(listener);
		getPanelControlled().getPlayButton().addMouseListener(listener);
		getPanelControlled().getStopButton().addMouseListener(listener);
		getPanelControlled().getNextButton().addMouseListener(listener);
		getPanelControlled().getPreviousButton().addMouseListener(listener);
		getPanelControlled().getVolumeButton().addActionListener(listener);
		getPanelControlled().getVolumeSlider().addChangeListener(listener);
		getPanelControlled().getBalanceSlider().addChangeListener(listener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.kernel.controllers.model.Controller#addStateBindings
	 * ()
	 */
	@Override
	protected void addStateBindings() {
		// Nothing to do
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.kernel.controllers.model.Controller#notifyReload()
	 */
	@Override
	protected void notifyReload() {
		// Nothing to do
	}

	/**
	 * Sets the max duration.
	 * 
	 * @param maxDuration
	 *            the new max duration
	 */
	// TODO: Rename to setAudioObjectLength
	public void setMaxDuration(long maxDuration) {
		getLogger().debug(LogCategories.CONTROLLER, new String[] { Long.toString(maxDuration) });

		getPanelControlled().getProgressBar().setMaximum((int) maxDuration);
	}

	/**
	 * Sets the mute.
	 * 
	 * @param mute
	 *            the new mute
	 */
	public void setMute(boolean mute) {
		getPanelControlled().getVolumeButton().setSelected(mute);
		if (mute) {
			getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MUTE);
		} else {
			int value = getPanelControlled().getVolumeSlider().getValue();
			if (value > 80) {
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOlUME_MAX);
			} else if (value > 40) {
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MED);
			} else if (value > 5) {
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_MIN);
			} else {
				getPanelControlled().getVolumeButton().setIcon(ImageLoader.VOLUME_ZERO);
			}
		}
	}

	/**
	 * Sets the playing.
	 * 
	 * @param playing
	 *            the new playing
	 */
	public void setPlaying(boolean playing) {
		getPanelControlled().setPlaying(playing);
	}

	/**
	 * Sets the slidable.
	 * 
	 * @param slidable
	 *            the new slidable
	 */
	public void setSlidable(boolean slidable) {
		getPanelControlled().getProgressBar().setEnabled(slidable);
	}

	/**
	 * Sets the time.
	 * 
	 * @param time
	 *            the time
	 * @param totalTime
	 *            the total time
	 */
	// TODO: Rename to setCurrentAudioObjectPlayedTime
	public void setTime(long time, long totalTime) {
		long remainingTime = totalTime - time;
		if (time == 0) {
			getPanelControlled().getRemainingTime().setText(TimeUtils.milliseconds2String(time));
		} else {
			getPanelControlled().getRemainingTime().setText(remainingTime > 0 ? StringUtils.getString("- ", TimeUtils.milliseconds2String(remainingTime)) : "-");
		}

		getPanelControlled().getTime().setText(TimeUtils.milliseconds2String(time));
		getPanelControlled().getProgressBar().setValue((int) time);
	}

	/**
	 * Sets the volume.
	 * 
	 * @param value
	 *            the new volume
	 */
	protected void setVolume(int value) {
		getPanelControlled().getVolumeSlider().setValue(value);
	}

}
